@@ -6,7 +6,7 @@
 # The OpsRamp metrics API is spread all over the place. This is a simple
 # initial class to expose the "get metric time series values" API.
 #
-# (c) Copyright 2020-2021 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2020-2022 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,7 +24,8 @@ from opsramp.api import ORapi
 
 
 class MetricsApi(ORapi):
-    '''The OpsRamp metrics API is spread all over the place. This is a simple
-    initial class to expose the complete /metric (note no "s") tree.'''
+    """The OpsRamp metrics API is spread all over the place. This is a simple
+    initial class to expose the complete /metric (note no "s") tree."""
+
     def __init__(self, parent):
-        super(MetricsApi, self).__init__(parent.api, 'metric')
+        super(MetricsApi, self).__init__(parent.api, "metric")
