@@ -2,7 +2,7 @@
 #
 # Exercise the opsramp module as an illustration of how to use it.
 #
-# (c) Copyright 2020-2021 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2020-2022 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,40 +16,37 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import os
-import logging
 import argparse
+import logging
+import os
 
 import opsramp.binding
 
 
 def connect():
-    url = os.environ['OPSRAMP_URL']
-    key = os.environ['OPSRAMP_KEY']
-    secret = os.environ['OPSRAMP_SECRET']
+    url = os.environ["OPSRAMP_URL"]
+    key = os.environ["OPSRAMP_KEY"]
+    secret = os.environ["OPSRAMP_SECRET"]
     return opsramp.binding.connect(url, key, secret)
 
 
 def parse_argv():
     parser = argparse.ArgumentParser()
-    parser.add_argument(
-        '-d', '--debug',
-        action='store_true'
-    )
+    parser.add_argument("-d", "--debug", action="store_true")
     ns = parser.parse_args()
     return ns
 
 
 def walk(service_maps, map):
-    if map['childType'] != 'SERVICE':
+    if map["childType"] != "SERVICE":
         # print("LEAF! %s %s" % (map['id'], map['name']))
         print("LEAF! %s" % map)
     else:
         # print("BRANCH! %s %s" % (map['id'], map['name']))
         print("BRANCH! %s" % map)
-        maps = service_maps.get(map['id'])
-        if 'results' in maps:
-            for submap in maps['results']:
+        maps = service_maps.get(map["id"])
+        if "results" in maps:
+            for submap in maps["results"]:
                 walk(service_maps, submap)
 
 
@@ -59,14 +56,14 @@ def main():
         logging.basicConfig()
         logging.getLogger().setLevel(logging.DEBUG)
 
-    tnt_id = os.environ['OPSRAMP_TENANT_ID']
+    tnt_id = os.environ["OPSRAMP_TENANT_ID"]
 
     ormp = connect()
     tnt = ormp.tenant(tnt_id)
 
     service_maps = tnt.service_maps()
     resp = service_maps.get()
-    for map in resp['results']:
+    for map in resp["results"]:
         walk(service_maps, map)
 
 
